@@ -1,9 +1,7 @@
 """
 Implements a client class to query the
-`Deezer API <http://developers.deezer.com/api>`_
+`Deezer API <https://developers.deezer.com/api>`_
 """
-import warnings
-
 import requests
 
 from deezer.resources import (
@@ -21,11 +19,6 @@ from deezer.resources import (
     User,
 )
 
-DEPRECATED_ARG_MESSAGE = (
-    "The `{arg_name}` keyword argument is deprecated "
-    "and will be removed in the next major release."
-)
-
 
 class Client:
     """
@@ -50,13 +43,6 @@ class Client:
     :param app_secret: application secret.
     :param access_token: user access token.
     :param headers: a dictionary of headers to be used.
-
-    .. deprecated:: 1.4.0
-
-        The following parameters will be removed in the next major version:
-
-            * **host** - override the default hostname.
-            * **use_ssl** - connect using HTTP if set to `False`.
     """
 
     objects_types = {
@@ -82,31 +68,12 @@ class Client:
         self.app_id = app_id
         self.app_secret = app_secret
         self.access_token = access_token
-        self.host = "api.deezer.com"
-        self.use_ssl = True
         self.session = requests.Session()
 
-        # Deprecated arguments
-        deprecated_kwargs = ["host", "use_ssl"]
-        for arg_name in deprecated_kwargs:
-            arg_value = kwargs.get(arg_name)
-            if arg_value is not None:
-                warnings.warn(DEPRECATED_ARG_MESSAGE.format(arg_name=arg_name))
-                setattr(self, arg_name, arg_value)
-
-        if kwargs.get("do_not_compress_reponse"):
-            warnings.warn(
-                DEPRECATED_ARG_MESSAGE.format(arg_name="do_not_compress_reponse")
-            )
-            self.session.headers.update({"Accept-Encoding": "identity"})
-
         # Headers
         if headers:
             self.session.headers.update(headers)
 
-        self.options = kwargs
-        self._authorize_url = None
-
     def _process_json(self, item, parent=None):
         """
         Recursively convert dictionary
@@ -135,16 +102,10 @@ class Client:
             object_class = self.objects_types[parent]
         return object_class(self, result)
 
-    @property
-    def scheme(self):
-        """
-        Get the http prefix for the address depending on the use_ssl attribute
-        """
-        return self.use_ssl and "https" or "http"
-
-    def url(self, request_path=""):
+    @staticmethod
+    def url(request_path=""):
         """Build the url with the appended request if provided."""
-        return f"{self.scheme}://{self.host}/{request_path}"
+        return f"https://api.deezer.com/{request_path}"
 
     def object_url(self, object_t, object_id=None, relation=None):
         """
